Module blaxel.core.client.models.trigger
========================================

Classes
-------

`Trigger(configuration: blaxel.core.client.types.Unset | ForwardRef('TriggerConfiguration') = <blaxel.core.client.types.Unset object>, id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, type_: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Trigger configuration
    
    Attributes:
        configuration (Union[Unset, TriggerConfiguration]): The configuration of the trigger
        id (Union[Unset, str]): The id of the trigger
        type_ (Union[Unset, str]): The type of trigger, can be http or http-async
    
    Method generated by attrs for class Trigger.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `configuration`
    :

    `id`
    :

    `type_`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :